Species Sensitivity Data provided by the Department of Agriculture Water and the Environment, Australia. This data underpins the ANZG default guideline for ametryn in freshwater.
Details
These data are licensed under CC BY 4.0 (summary of terms provided here: https://creativecommons.org/licenses/by/4.0/) Additional information is available from the Water Quality website at https://www.waterquality.gov.au/
Please cite these data as: ANZG (2025). “Toxicant default guideline values for aquatic ecosystem protection: Ametryn in freshwater.” Australian and New Zealand Governments and Australian State and Territory Governments, Canberra, Australia. https://www.waterquality.gov.au/sites/default/files/documents/ametryn-fresh-dgvs-technical-brief.pdf.
The columns are as follows:
- Conc
The chemical concentration in micrograms per Litre (dbl).
- Duration
The duration of the test in days (chr).
- Genus
The Genus name (chr).
- Group
The taxonomic group (chr).
- Species
The species binomial name (chr).
- Toxicity_measure
The toxicity measure used (chr).
- Units
The concentration units of Conc (micrograms per Litre, ug/L) (chr).
Where toxicity measure is not a chronic NEC, EC10 or NOEC value,
concentration has been converted using the appropriate default ratio, as
follows: 10 from acute EC50/LC50 to chronic EC10; 5 from chronic EC50 to
EC10; 2.5 from LOEC to EC10. Please see the primary reference material for
more information.
Examples
print(anzg_ametryn_fresh, n=Inf)
#> # A tibble: 8 × 7
#> Conc Duration Genus Group Species Toxicity_measure Units
#> <dbl> <chr> <chr> <chr> <chr> <chr> <chr>
#> 1 0.06 96 Chlorella Green alga pyrenoidosa Chronic EC50 ug/L
#> 2 2000 240 Chlorococcum Green alga sp. Chronic EC50 ug/L
#> 3 7.2 72 Neochloris Green alga sp. Chronic EC50 ug/L
#> 4 4.8 72 Platymonas Green alga sp. Chronic EC50 ug/L
#> 5 30 96 Scenedesmus Green alga quadricauda Chronic EC50 ug/L
#> 6 1.14 168 Selenastrum Green alga capricornutum Chronic NOEL ug/L
#> 7 2 168 Lemna Macrophyte gibba Chronic NOEL ug/L
#> 8 5.2 72 Stauroneis Diatom amphoroides Chronic EC50 ug/L