get_ssddata: Get SSD dataset
Description
Retrieves a specific SSD dataset,
filtering and groups by species and applies a geometric
mean in the case of duplicate records.
Usage
get_ssddata(
dataset_name,
filter_val = NULL,
use_gmmean = TRUE,
spp_vec = c("Species", "Genus"),
conc = "Conc"
)Arguments
dataset_name
The name (chr) of the desired dataset in ssddata.
filter_val
A character string,
indicating the filter to be applied (value)
(colname) and which column it applies to, separated by "_".
Must be in the form colname_value.
use_gmmean
Logical indicating if a geometric mean should be applied.
spp_vec
The group_by columns to use for grouping
data and applying a geometric mean.
conc
The name of the concentration (x data) column.
Value
The data.frame for dataset_name with any applied groupings and summary.
Examples
Run this code# NOT RUN {
get_ssddata("ccme_boron")
# }
Run the code above in your browser using DataLab